@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 
 from sym.cli.data.request_data import RequestData
+from sym.cli.errors import CliError
 from sym.cli.helpers.check.model import SymCheck
 
 
@@ -19,7 +20,7 @@ class SymAction(ABC):
         """
 
         if not request_data.resource:
-            raise ValueError("RequestData must have a resource.")
+            raise CliError("must specify a resource.")
 
     def get_requirements(self) -> [SymCheck]:
         return []
@@ -38,7 +39,7 @@ class SymAction(ABC):
                     )
 
         if len(failures) > 0:
-            raise RuntimeError(failures)
+            raise CliError(failures)
 
     @abstractmethod
     def execute(self, request_data: RequestData):
