@@ -242,7 +242,7 @@ def gen_local_ssh_config(client) -> SymConfigFile:
             PasswordAuthentication no
             ChallengeResponseAuthentication no
             GSSAPIAuthentication no
-            ProxyCommand sh -c "{sym_cmd} || exit \$?"
+            ProxyCommand sh -c "{sym_cmd} || exit \\$?"
             {mux_config.strip()}
         """
     ))
