@@ -1,8 +1,11 @@
 import shlex
+import subprocess
 from configparser import ConfigParser, NoOptionError
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
+from semver import VersionInfo
+
 from ..decorators import command_require_bins, intercept_errors, run_subprocess
 from ..errors import (
     ExpiredCredentials,
@@ -17,6 +20,8 @@ from ..helpers.keywords_to_options import Argument, Options, keywords_to_options
 from ..helpers.params import Profile, get_saml2aws_params
 from .saml_client import SAMLClient
 
+MIN_VERSION = VersionInfo.parse("2.26.2")
+
 ErrorPatterns = {
     Saml2AwsNoRoles: UnavailableResourceError,
     Saml2AwsNoCreds: SamlClientNotSetup,
@@ -29,7 +34,7 @@ class Saml2Aws(SAMLClient):
     binary = "saml2aws"
     option_value = "saml2aws"
     priority = 10
-    setup_help = "Run `saml2aws login`."
+    setup_help = "Upgrade to the latest version, then run `saml2aws login`."
 
     resource: str
     options: "GlobalOptionsBase"
@@ -47,10 +52,25 @@ class Saml2Aws(SAMLClient):
             "skip_prompt": True,
         }
 
+    def _check_version(self) -> bool:
+        # Can't use run_subprocess because saml2aws annoyingly outputs the version on stderr
+        version = subprocess.run(
+            ["saml2aws", "--version"],
+            text=True,
+            capture_output=True,
+        ).stderr
+        if not version:
+            return False
+        return VersionInfo.parse(version.strip()) >= MIN_VERSION
+
     def is_setup(self) -> bool:
         path = Path.home() / ".saml2aws"
         if not path.exists():
             return False
+
+        if not self._check_version():
+            return False
+
         config = ConfigParser()
         config.read(path)
         for section in config.sections():
