@@ -20,8 +20,11 @@ def time_travel() -> Iterator:
 
 
 @pytest.fixture
-def pypi_response() -> dict:
-    return json.load((Path(__file__).parent / "response.json").open())
+def pypi_response():
+    def responder(name) -> dict:
+        return json.load((Path(__file__).parent / "responses" / f"{name}.json").open())
+
+    return responder
 
 
 @pytest.fixture
@@ -33,7 +36,12 @@ def http_mock(pypi_response) -> Iterator:
             rsps.add(
                 responses.GET,
                 "https://pypi.org/pypi/sym-cli/json",
-                json=pypi_response,
+                json=pypi_response("sym-cli"),
+            )
+            rsps.add(
+                responses.GET,
+                "https://pypi.org/pypi/sym-cli/0.0.66/json",
+                json=pypi_response("sym-cli-66"),
             )
         yield rsps
 
@@ -53,6 +61,14 @@ def other_updater(sandbox, updater) -> SymUpdater:
     return updater
 
 
+@pytest.fixture
+def sitepackage_updater(sandbox, updater) -> SymUpdater:
+    root = Path() / "foo"
+    sandbox.create_binary(root / "bin" / "pip")
+    updater.dir = sandbox.create_dir(root / "lib" / "python3.8" / "site-packages")
+    return updater
+
+
 @pytest.fixture
 def pipx_updater(sandbox, updater) -> SymUpdater:
     sandbox.create_binary("bin/pipx")
